<?php

declare(strict_types = 1);

namespace Drupal\ui_suite_bootstrap\HookHandler;

use Drupal\Core\Template\Attribute;
use Drupal\ui_patterns_settings\Plugin\UiPatterns\SettingType\LinksSettingType;

/**
 * Ensure menu structure fits into links prop structure.
 */
class PreprocessMenu {

  /**
   * Ensure menu structure fits into links prop structure.
   *
   * @param array $variables
   *   The preprocessed variables.
   */
  public function preprocess(array &$variables): void {
    $variables['preprocessed_items'] = LinksSettingType::normalize($variables['items']);
    $this->addActiveClass($variables['preprocessed_items']);
  }

  /**
   * Add active class on link if in active trail.
   *
   * @param array $items
   *   The items to process.
   */
  protected function addActiveClass(array &$items): void {
    foreach ($items as &$item) {
      if ($item['in_active_trail']) {
        if (isset($item['link_attributes'])) {
          $item['link_attributes']->addClass('active');
        }
        else {
          $item['link_attributes'] = new Attribute([
            'class' => [
              'active',
            ],
          ]);
        }
      }
      if ($item['below']) {
        $this->addActiveClass($item['below']);
      }
    }
  }

}
